@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Scalar::Util ();
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 my %SPECIAL_OPS = (
     query => {
@@ -1253,6 +1253,20 @@ sub _filter_field_terms {
                 }
                 return $self->_join_clauses( 'filter', 'or', \@filters );
             },
+            HASHREF => sub {
+                my $v = delete $val->{value};
+                $v = $v->[0] if ref $v eq 'ARRAY' and @$v < 2;
+                croak "Missing 'value' param in 'terms' filter"
+                    unless defined $v;
+
+                if ( ref $v eq 'ARRAY' ) {
+                    my $p
+                        = $self->_hash_params( $op, $val, [], ['execution'] );
+                    $p->{$k} = $v;
+                    return { terms => $p };
+                }
+                return { term => { $k => $v } };
+            },
         }
     );
 }
@@ -1547,9 +1561,9 @@ ElasticSearch::SearchBuilder - A Perlish compact query language for ElasticSearc
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
 
-Compatible with ElasticSearch version 0.19.0RC2
+Compatible with ElasticSearch version 0.19.0
 
 =cut
 
@@ -2135,10 +2149,21 @@ C<< <> >> and C<!=> are synonyms:
     { foo => { '!=' => ['bar','baz'] }}
     { foo => { '<>' => ['bar','baz'] }}
 
+The C<terms> filter can take an C<execution> parameter which affects how the
+filter of multiple terms is executed and cached.
+
+For instance:
+
+    { foo => {
+        -terms => {
+            value       => ['foo','bar'],
+            execution   => 'bool'
+        }
+    }}
+
 See L<Term Filter|http://www.elasticsearch.org/guide/reference/query-dsl/term-filter.html>
 and L<Terms Filter|http://www.elasticsearch.org/guide/reference/query-dsl/terms-filter.html>
 
-
 =head1 RANGES
 
 =head2 lt | gt | lte | gte | < | <= | >= | > | -range | -not_range
